IAED: Introduction to algorithms and data structures

1. search: linear and binary
2. sorting: selection, insertion, bubble, shell, quick, merge, heap, counting, readix LSB/MSB
3. hash-tables: external, linear probing, double hashing
4. tree: binary search, AVL
5. graph: breadth transversal, depth transversal

&copy; Pedro Reis dos Santos, IST Ulisboa, 2026
